@@ -1,7 +1,7 @@
 // Copyright (c) Jupyter Development Team.
 // Distributed under the terms of the Modified BSD License.
 import { IJupyterLabPageFixture } from '@jupyterlab/galata';
-import { ElementHandle, Locator } from '@playwright/test';
+import { Locator } from '@playwright/test';
 
 const OUTER_SELECTOR = '.jp-WindowedPanel-outer';
 const DRAGGABLE_AREA = '.jp-InputArea-prompt';
@@ -10,12 +10,10 @@ const DRAGGABLE_AREA = '.jp-InputArea-prompt';
  * Measure how much of the **notebook** viewport does a cell take up.
  */
 export async function notebookViewportRatio(
-  notebook: ElementHandle,
-  cell: ElementHandle
+  notebook: Locator,
+  cell: Locator
 ): Promise<number> {
-  const scroller = (await notebook.$(
-    OUTER_SELECTOR
-  )) as ElementHandle<HTMLElement>;
+  const scroller = notebook.locator(OUTER_SELECTOR).first();
   const n = await scroller.boundingBox();
   const c = await cell.boundingBox();
   const cellBottom = c.y + c.height;
@@ -36,13 +34,11 @@ export async function notebookViewportRatio(
  */
 export async function positionCellPartiallyBelowViewport(
   page: IJupyterLabPageFixture,
-  notebook: ElementHandle,
-  cell: ElementHandle,
+  notebook: Locator,
+  cell: Locator,
   ratio: number
 ): Promise<void> {
-  const scroller = (await notebook.$(
-    OUTER_SELECTOR
-  )) as ElementHandle<HTMLElement>;
+  const scroller = notebook.locator(OUTER_SELECTOR).first();
   const notebookBbox = await scroller.boundingBox();
   const cellBbox = await cell.boundingBox();
   await page.mouse.move(notebookBbox.x, notebookBbox.y);
@@ -79,34 +75,20 @@ export async function dragCellTo(
 }
 
 /**
- * Set the sidebar width
- *
- * @param page Page object
- * @param width Sidebar width in pixels
- * @param side Which sidebar to set: 'left' or 'right'
+ * Check if a given string value is valid JSON.
  */
-export async function setSidebarWidth(
-  page: IJupyterLabPageFixture,
-  width = 251,
-  side: 'left' | 'right' = 'left'
-): Promise<void> {
-  const handles = page.locator(
-    '#jp-main-split-panel > .lm-SplitPanel-handle:not(.lm-mod-hidden)'
-  );
-  const splitHandle =
-    side === 'left'
-      ? await handles.first().elementHandle()
-      : await handles.last().elementHandle();
-  const handleBBox = await splitHandle.boundingBox();
+export function isValidJSON(value: string): boolean {
+  try {
+    JSON.parse(value);
+    return true;
+  } catch (e) {
+    return false;
+  }
+}
 
-  await page.mouse.move(
-    handleBBox.x + 0.5 * handleBBox.width,
-    handleBBox.y + 0.5 * handleBBox.height
-  );
-  await page.mouse.down();
-  await page.mouse.move(
-    side === 'left' ? 33 + width : page.viewportSize().width - 33 - width,
-    handleBBox.y + 0.5 * handleBBox.height
-  );
-  await page.mouse.up();
+/**
+ * Check if a given string value is empty (excluding spaces).
+ */
+export function isBlank(value: string): boolean {
+  return value.trim().length === 0;
 }
