@@ -1,12 +1,11 @@
-# coding: utf-8
 """An error handler for JupyterLab."""
 
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
 
+from jupyter_server.base.handlers import JupyterHandler
+from jupyter_server.extension.handler import ExtensionHandlerMixin
 from tornado import web
-from jupyterlab_server.server import JupyterHandler
-
 
 TEMPLATE = """
 <!DOCTYPE HTML>
@@ -21,13 +20,14 @@ TEMPLATE = """
 </body>
 """
 
-class ErrorHandler(JupyterHandler):
 
-    def initialize(self, messages):
+class ErrorHandler(ExtensionHandlerMixin, JupyterHandler):
+    def initialize(self, messages=None, name=None):
+        super().initialize(name=name)
         self.messages = messages
 
     @web.authenticated
     @web.removeslash
     def get(self):
-        msgs = ['<h2>%s</h2>' % msg for msg in self.messages]
-        self.write(TEMPLATE % '\n'.join(msgs))
+        msgs = ["<h2>%s</h2>" % msg for msg in self.messages]
+        self.write(TEMPLATE % "\n".join(msgs))
